function embryo = create_embryo(file_name)

%CREATE_EMBRYO   Reads in a MulteeSum embryo file and creates an embryo
%data structure
%
% embryo = CREATE_EMBRYO( file_name )
%
% embryo: returned data structure containing embryo data
%
% file_name: embryo .csv file
%

fid = fopen( file_name );

% read in the comment lines
s = fgetl(fid);
while (s(1) == '#') && (s(2) == '#')
  s = fgetl(fid);
end

% get the species name
[token,r] = strtok(s,':');
[token,r] = strtok(r,': ,');
embryo.name = token;

% get the number of cells
s = fgetl(fid);
[token,r] = strtok(s,':');
[token,r] = strtok(r,': ,');
embryo.num_cells = str2num(token);

a = importdata( file_name );

% get the name of the embryo
%[token,r] = strtok(a.textdata(size(a.textdata)-2), ':');
%[token,r] = strtok(r(1), ': ');
%embryo.name = cell2mat(token);

% take the second to last line of the head to get the number of cells
%[token,r] = strtok(a.textdata(size(a.textdata)-1), ':');
%[token,r] = strtok(r(1), ': ');
%embryo.num_cells = str2num(cell2mat(token));

% get the cell ids and 3D positions
embryo.id = a.data(:,1);

embryo.pos = a.data(:,2);
embryo.pos(:,2) = a.data(:,3);
embryo.pos(:,3) = a.data(:,4);

% get the expression profiles
i = size(a.colheaders);
embryo.expression_profile_header = a.colheaders(7:i(2));
embryo.expression_profile = a.data(:,7:i(2));